Class: Google::Apis::FormsV1::Grid

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/forms_v1/classes.rb,
lib/google/apis/forms_v1/representations.rb,
lib/google/apis/forms_v1/representations.rb

Overview

A grid of choices (radio or check boxes) with each row constituting a separate question. Each row has the same choices, which are shown as the columns.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Grid

Returns a new instance of Grid.



775
776
777
# File 'lib/google/apis/forms_v1/classes.rb', line 775

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnsGoogle::Apis::FormsV1::ChoiceQuestion

A radio/checkbox/dropdown question. Corresponds to the JSON property columns



766
767
768
# File 'lib/google/apis/forms_v1/classes.rb', line 766

def columns
  @columns
end

#shuffle_questionsBoolean Also known as: shuffle_questions?

If true, the questions are randomly ordered. In other words, the rows appear in a different order for every respondent. Corresponds to the JSON property shuffleQuestions

Returns:

  • (Boolean)


772
773
774
# File 'lib/google/apis/forms_v1/classes.rb', line 772

def shuffle_questions
  @shuffle_questions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



780
781
782
783
# File 'lib/google/apis/forms_v1/classes.rb', line 780

def update!(**args)
  @columns = args[:columns] if args.key?(:columns)
  @shuffle_questions = args[:shuffle_questions] if args.key?(:shuffle_questions)
end