Class: Google::Apis::FormsV1::Image
- Inherits:
-
Object
- Object
- Google::Apis::FormsV1::Image
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/forms_v1/classes.rb,
lib/google/apis/forms_v1/representations.rb,
lib/google/apis/forms_v1/representations.rb
Overview
Data representing an image.
Instance Attribute Summary collapse
-
#alt_text ⇒ String
A description of the image that is shown on hover and read by screenreaders.
-
#content_uri ⇒ String
Output only.
-
#properties ⇒ Google::Apis::FormsV1::MediaProperties
Properties of the media.
-
#source_uri ⇒ String
Input only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Image
constructor
A new instance of Image.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Image
Returns a new instance of Image.
812 813 814 |
# File 'lib/google/apis/forms_v1/classes.rb', line 812 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alt_text ⇒ String
A description of the image that is shown on hover and read by screenreaders.
Corresponds to the JSON property altText
793 794 795 |
# File 'lib/google/apis/forms_v1/classes.rb', line 793 def alt_text @alt_text end |
#content_uri ⇒ String
Output only. A URI from which you can download the image; this is valid only
for a limited time.
Corresponds to the JSON property contentUri
799 800 801 |
# File 'lib/google/apis/forms_v1/classes.rb', line 799 def content_uri @content_uri end |
#properties ⇒ Google::Apis::FormsV1::MediaProperties
Properties of the media.
Corresponds to the JSON property properties
804 805 806 |
# File 'lib/google/apis/forms_v1/classes.rb', line 804 def properties @properties end |
#source_uri ⇒ String
Input only. The source URI is the URI used to insert the image. The source URI
can be empty when fetched.
Corresponds to the JSON property sourceUri
810 811 812 |
# File 'lib/google/apis/forms_v1/classes.rb', line 810 def source_uri @source_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
817 818 819 820 821 822 |
# File 'lib/google/apis/forms_v1/classes.rb', line 817 def update!(**args) @alt_text = args[:alt_text] if args.key?(:alt_text) @content_uri = args[:content_uri] if args.key?(:content_uri) @properties = args[:properties] if args.key?(:properties) @source_uri = args[:source_uri] if args.key?(:source_uri) end |