Class: Google::Apis::FormsV1::Info
- Inherits:
-
Object
- Object
- Google::Apis::FormsV1::Info
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/forms_v1/classes.rb,
lib/google/apis/forms_v1/representations.rb,
lib/google/apis/forms_v1/representations.rb
Overview
The general information for a form.
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the form.
-
#document_title ⇒ String
Output only.
-
#title ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Info
constructor
A new instance of Info.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Info
Returns a new instance of Info.
868 869 870 |
# File 'lib/google/apis/forms_v1/classes.rb', line 868 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
The description of the form.
Corresponds to the JSON property description
851 852 853 |
# File 'lib/google/apis/forms_v1/classes.rb', line 851 def description @description end |
#document_title ⇒ String
Output only. The title of the document which is visible in Drive. If Info.
title is empty, document_title may appear in its place in the Google Forms
UI and be visible to responders. document_title can be set on create, but
cannot be modified by a batchUpdate request. Please use the Google Drive API if you need
to programmatically update document_title.
Corresponds to the JSON property documentTitle
861 862 863 |
# File 'lib/google/apis/forms_v1/classes.rb', line 861 def document_title @document_title end |
#title ⇒ String
Required. The title of the form which is visible to responders.
Corresponds to the JSON property title
866 867 868 |
# File 'lib/google/apis/forms_v1/classes.rb', line 866 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
873 874 875 876 877 |
# File 'lib/google/apis/forms_v1/classes.rb', line 873 def update!(**args) @description = args[:description] if args.key?(:description) @document_title = args[:document_title] if args.key?(:document_title) @title = args[:title] if args.key?(:title) end |