Class: Google::Apis::FormsV1::PublishState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/forms_v1/classes.rb,
lib/google/apis/forms_v1/representations.rb,
lib/google/apis/forms_v1/representations.rb

Overview

The publishing state of a form.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublishState

Returns a new instance of PublishState.



1165
1166
1167
# File 'lib/google/apis/forms_v1/classes.rb', line 1165

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#is_accepting_responsesBoolean Also known as: is_accepting_responses?

Required. Whether the form accepts responses. If is_published is set to false, this field is forced to false. Corresponds to the JSON property isAcceptingResponses

Returns:

  • (Boolean)


1156
1157
1158
# File 'lib/google/apis/forms_v1/classes.rb', line 1156

def is_accepting_responses
  @is_accepting_responses
end

#is_publishedBoolean Also known as: is_published?

Required. Whether the form is published and visible to others. Corresponds to the JSON property isPublished

Returns:

  • (Boolean)


1162
1163
1164
# File 'lib/google/apis/forms_v1/classes.rb', line 1162

def is_published
  @is_published
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1170
1171
1172
1173
# File 'lib/google/apis/forms_v1/classes.rb', line 1170

def update!(**args)
  @is_accepting_responses = args[:is_accepting_responses] if args.key?(:is_accepting_responses)
  @is_published = args[:is_published] if args.key?(:is_published)
end