Class: Google::Apis::FormsV1::QuestionGroupItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/forms_v1/classes.rb,
lib/google/apis/forms_v1/representations.rb,
lib/google/apis/forms_v1/representations.rb

Overview

Defines a question that comprises multiple questions grouped together.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QuestionGroupItem

Returns a new instance of QuestionGroupItem.



1281
1282
1283
# File 'lib/google/apis/forms_v1/classes.rb', line 1281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gridGoogle::Apis::FormsV1::Grid

A grid of choices (radio or check boxes) with each row constituting a separate question. Each row has the same choices, which are shown as the columns. Corresponds to the JSON property grid



1267
1268
1269
# File 'lib/google/apis/forms_v1/classes.rb', line 1267

def grid
  @grid
end

#imageGoogle::Apis::FormsV1::Image

Data representing an image. Corresponds to the JSON property image



1272
1273
1274
# File 'lib/google/apis/forms_v1/classes.rb', line 1272

def image
  @image
end

#questionsArray<Google::Apis::FormsV1::Question>

Required. A list of questions that belong in this question group. A question must only belong to one group. The kind of the group may affect what types of questions are allowed. Corresponds to the JSON property questions



1279
1280
1281
# File 'lib/google/apis/forms_v1/classes.rb', line 1279

def questions
  @questions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1286
1287
1288
1289
1290
# File 'lib/google/apis/forms_v1/classes.rb', line 1286

def update!(**args)
  @grid = args[:grid] if args.key?(:grid)
  @image = args[:image] if args.key?(:image)
  @questions = args[:questions] if args.key?(:questions)
end