Class: Google::Apis::FormsV1::QuizSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/forms_v1/classes.rb,
lib/google/apis/forms_v1/representations.rb,
lib/google/apis/forms_v1/representations.rb

Overview

Settings related to quiz forms and grading. These must be updated with the UpdateSettingsRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QuizSettings

Returns a new instance of QuizSettings.



1330
1331
1332
# File 'lib/google/apis/forms_v1/classes.rb', line 1330

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#is_quizBoolean Also known as: is_quiz?

Whether this form is a quiz or not. When true, responses are graded based on question Grading. Upon setting to false, all question Grading is deleted. Corresponds to the JSON property isQuiz

Returns:

  • (Boolean)


1327
1328
1329
# File 'lib/google/apis/forms_v1/classes.rb', line 1327

def is_quiz
  @is_quiz
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1335
1336
1337
# File 'lib/google/apis/forms_v1/classes.rb', line 1335

def update!(**args)
  @is_quiz = args[:is_quiz] if args.key?(:is_quiz)
end