Class: Google::Apis::FormsV1::RowQuestion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/forms_v1/classes.rb,
lib/google/apis/forms_v1/representations.rb,
lib/google/apis/forms_v1/representations.rb

Overview

Configuration for a question that is part of a question group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RowQuestion

Returns a new instance of RowQuestion.



1455
1456
1457
# File 'lib/google/apis/forms_v1/classes.rb', line 1455

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#titleString

Required. The title for the single row in the QuestionGroupItem. Corresponds to the JSON property title

Returns:

  • (String)


1453
1454
1455
# File 'lib/google/apis/forms_v1/classes.rb', line 1453

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1460
1461
1462
# File 'lib/google/apis/forms_v1/classes.rb', line 1460

def update!(**args)
  @title = args[:title] if args.key?(:title)
end