Class: Google::Apis::FormsV1::ScaleQuestion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/forms_v1/classes.rb,
lib/google/apis/forms_v1/representations.rb,
lib/google/apis/forms_v1/representations.rb

Overview

A scale question. The user has a range of numeric values to choose from.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ScaleQuestion

Returns a new instance of ScaleQuestion.



1489
1490
1491
# File 'lib/google/apis/forms_v1/classes.rb', line 1489

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#highFixnum

Required. The highest possible value for the scale. Corresponds to the JSON property high

Returns:

  • (Fixnum)


1472
1473
1474
# File 'lib/google/apis/forms_v1/classes.rb', line 1472

def high
  @high
end

#high_labelString

The label to display describing the highest point on the scale. Corresponds to the JSON property highLabel

Returns:

  • (String)


1477
1478
1479
# File 'lib/google/apis/forms_v1/classes.rb', line 1477

def high_label
  @high_label
end

#lowFixnum

Required. The lowest possible value for the scale. Corresponds to the JSON property low

Returns:

  • (Fixnum)


1482
1483
1484
# File 'lib/google/apis/forms_v1/classes.rb', line 1482

def low
  @low
end

#low_labelString

The label to display describing the lowest point on the scale. Corresponds to the JSON property lowLabel

Returns:

  • (String)


1487
1488
1489
# File 'lib/google/apis/forms_v1/classes.rb', line 1487

def low_label
  @low_label
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1494
1495
1496
1497
1498
1499
# File 'lib/google/apis/forms_v1/classes.rb', line 1494

def update!(**args)
  @high = args[:high] if args.key?(:high)
  @high_label = args[:high_label] if args.key?(:high_label)
  @low = args[:low] if args.key?(:low)
  @low_label = args[:low_label] if args.key?(:low_label)
end