Class: Google::Apis::FormsV1::TextQuestion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/forms_v1/classes.rb,
lib/google/apis/forms_v1/representations.rb,
lib/google/apis/forms_v1/representations.rb

Overview

A text-based question.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TextQuestion

Returns a new instance of TextQuestion.



1653
1654
1655
# File 'lib/google/apis/forms_v1/classes.rb', line 1653

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#paragraphBoolean Also known as: paragraph?

Whether the question is a paragraph question or not. If not, the question is a short text question. Corresponds to the JSON property paragraph

Returns:

  • (Boolean)


1650
1651
1652
# File 'lib/google/apis/forms_v1/classes.rb', line 1650

def paragraph
  @paragraph
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1658
1659
1660
# File 'lib/google/apis/forms_v1/classes.rb', line 1658

def update!(**args)
  @paragraph = args[:paragraph] if args.key?(:paragraph)
end